//--MASK BEGIN JPRINTF
///////////////////////////////////////////////////////////////////////////////
//                                                                           //
//  Notice to licensees:                                                     //
//                                                                           //
//  This source code is the exclusive, proprietary intellectual property of  //
//  Sharkysoft (sharkysoft.com).  You may view this source code as a         //
//  supplement to other product documentation, but you may not distribute    //
//  it or use it for any other purpose without written consent from          //
//  Sharkysoft.                                                              //
//                                                                           //
//  You are permitted to modify and recompile this source code, but you may  //
//  not remove this notice.  If you add features to or fix errors in this    //
//  code, please consider sharing your changes with Sharkysoft for possible  //
//  incorporation into future releases of the product.  Thanks!              //
//                                                                           //
//  For more information about Sharkysoft products and services, please      //
//  visit Sharkysoft on the web at                                           //
//                                                                           //
//       http://sharkysoft.com/                                              //
//                                                                           //
//  Thank you for using Lava!                                                //
//                                                                           //
///////////////////////////////////////////////////////////////////////////////



package lava.array;



/******************************************************************************
Casts between boolean arrays and arrays of other types.

<p><b>Details:</b>  <code>BooleanArrayCaster</code> functions convert arrays of primitive types into arrays of <code>booleans</code>, and vice versa.  When converting from <code>double</code>, <code>float</code>, <code>long</code>, <code>int</code>, <code>short</code>, <code>byte</code>, or <code>char</code> to <code>boolean</code>, the output is <code>true</code> only if the input is non-zero.  When going the other way, the output is 1 if the input is <code>true</code>, 0 otherwise.  When casting <code>Object</code> arrays to <code>boolean</code> arrays, the output is <code>true</code> only if the input is non-<code>null</code>.</p>

<p>The signatures for functions in this class follow the same rules as described in {@link ArrayCaster <code>ArrayCaster</code>}.</p>

@see ArrayCaster

@author Sharky
@since 1999.03.27
@version 1999.09.11
******************************************************************************/

public abstract class BooleanArrayCaster
//--MASK END JPRINTF
	extends ArrayCaster
//--MASK BEGIN JPRINTF
{



//--MASK END JPRINTF
	public final static double[] toDoubles
	(
		boolean[] src,
		int from,
		double[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new double [to + amt];
		for (int i = 0; i < amt; ++ i)
			dest [to + i] = src [from + i] ? (double) 1 : (double) 0;
		return dest;
	}



	public final static float[] toFloats
	(
		boolean[] src,
		int from,
		float[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new float [to + amt];
		for (int i = 0; i < amt; ++ i)
			dest [to + i] = src [from + i] ? (float) 1 : (float) 0;
		return dest;
	}



	public final static long[] toLongs
	(
		boolean[] src,
		int from,
		long[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new long [to + amt];
		for (int i = 0; i < amt; ++ i)
			dest [to + i] = src [from + i] ? (long) 1 : (long) 0;
		return dest;
	}



	public final static int[] toInts
	(
		boolean[] src,
		int from,
		int[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new int [to + amt];
		for (int i = 0; i < amt; ++ i)
			dest [to + i] = src [from + i] ? (int) 1 : (int) 0;
		return dest;
	}



	public final static short[] toShorts
	(
		boolean[] src,
		int from,
		short[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new short [to + amt];
		for (int i = 0; i < amt; ++ i)
			dest [to + i] = src [from + i] ? (short) 1 : (short) 0;
		return dest;
	}



	public final static byte[] toBytes
	(
		boolean[] src,
		int from,
		byte[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new byte [to + amt];
		for (int i = 0; i < amt; ++ i)
			dest [to + i] = src [from + i] ? (byte) 1 : (byte) 0;
		return dest;
	}



	public final static boolean[] toBooleans
	(
		double[] src,
		int from,
		boolean[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new boolean [to + amt];
		for (int i = 0; i < amt; ++ i)
			dest [to + i] = src [from + i] != 0;
		return dest;
	}



	public final static boolean[] toBooleans
	(
		float[] src,
		int from,
		boolean[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new boolean [to + amt];
		for (int i = 0; i < amt; ++ i)
			dest [to + i] = src [from + i] != 0;
		return dest;
	}



	public final static boolean[] toBooleans
	(
		long[] src,
		int from,
		boolean[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new boolean [to + amt];
		for (int i = 0; i < amt; ++ i)
			dest [to + i] = src [from + i] != 0;
		return dest;
	}



	public final static boolean[] toBooleans
	(
		int[] src,
		int from,
		boolean[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new boolean [to + amt];
		for (int i = 0; i < amt; ++ i)
			dest [to + i] = src [from + i] != 0;
		return dest;
	}



	public final static boolean[] toBooleans
	(
		short[] src,
		int from,
		boolean[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new boolean [to + amt];
		for (int i = 0; i < amt; ++ i)
			dest [to + i] = src [from + i] != 0;
		return dest;
	}



	public final static boolean[] toBooleans
	(
		byte[] src,
		int from,
		boolean[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new boolean [to + amt];
		for (int i = 0; i < amt; ++ i)
			dest [to + i] = src [from + i] != 0;
		return dest;
	}



	public final static boolean[] toBooleans
	(
		char[] src,
		int from,
		boolean[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new boolean [to + amt];
		for (int i = 0; i < amt; ++ i)
			dest [to + i] = src [from + i] != 0;
		return dest;
	}



	public final static char[] toChars
	(
		boolean[] src,
		int from,
		char[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new char [to + amt];
		for (int i = 0; i < amt; ++ i)
			dest [to + i] = src [from + i] ? (char) 1 : (char) 0;
		return dest;
	}



//--MASK BEGIN JPRINTF
	public final static boolean[] toBooleans
	(
		Object[] src,
		int from,
		boolean[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new boolean [to + amt];
		for (int i = 0; i < amt; ++ i)
			dest [to + i] = src [from + i] != null;
		return dest;
	}



}



