///////////////////////////////////////////////////////////////////////////////
//                                                                           //
//  Notice to licensees:                                                     //
//                                                                           //
//  This source code is the exclusive, proprietary intellectual property of  //
//  Sharkysoft (sharkysoft.com).  You may view this source code as a         //
//  supplement to other product documentation, but you may not distribute    //
//  it or use it for any other purpose without written consent from          //
//  Sharkysoft.                                                              //
//                                                                           //
//  You are permitted to modify and recompile this source code, but you may  //
//  not remove this notice.  If you add features to or fix errors in this    //
//  code, please consider sharing your changes with Sharkysoft for possible  //
//  incorporation into future releases of the product.  Thanks!              //
//                                                                           //
//  For more information about Sharkysoft products and services, please      //
//  visit Sharkysoft on the web at                                           //
//                                                                           //
//       http://sharkysoft.com/                                              //
//                                                                           //
//  Thank you for using Lava!                                                //
//                                                                           //
///////////////////////////////////////////////////////////////////////////////



package lava.riff;



import lava.util.BitTwiddler;



/******************************************************************************
RIFF file constants.

<p><b>Details:</b>  <code>Riff</code> contains functions and constants that are useful when processing RIFF files.</p>
******************************************************************************/

public class Riff
{



	private Riff () {throw new lava.UnreachableCodeException ();}



	/**********************************************************************
	Encodes chunk tag.

	<p><b>Details:</b>  <code>makeIntTag</code> generates an <code>int</code> that represents a four character chunk tag (chunk type identifier).  This function is used primarily to form the chunk tag constants that are used in other RIFF-related classes in this package.  (In this package, tags are processed as <code>int</code>s, rather than strings, because comparing two <code>int</code>s is more efficient than comparing two strings.)  The MSB of the returned <code>int</code> is the first character in the tag string.  The tag must be exactly four 8-bit characters.  (Pad with spaces if necessary.)

	@param stag the tag in <code>String</code> form
	@return the tag in <code>int</code> form
	@see #decodeTag(int)
	**********************************************************************/

	public final static int makeIntTag (String stag)
	{
		if (stag . length () != 4)
			throw new IllegalArgumentException ();
		return BitTwiddler.toIntBe (stag . getBytes ());
	}



	/**********************************************************************
	Decodes tag.

	<p><b>Details:</b>  <code>decodeTag</code> converts a chunk tag (chunk type identifier) from its <code>int</code> form to <code>String</code> form.  This is the inverse function of <code>makeIntTag</code>.</p>

	@param itag the tag in <code>int</code> form
	@return the tag in <code>String</code> form
	@see #makeIntTag(java.lang.String)
	**********************************************************************/

	public final static String decodeTag (int itag)
	{
		return new String
		(
			BitTwiddler.toBytesBe (itag, new byte [4], 0)
		);
	}



	/**********************************************************************
	RIFF tag.

	<p><b>Details:</b>  This member defines the 'RIFF' tag, or the "magic number" found in the first four bytes of a RIFF file.</p>
	**********************************************************************/

	public static final int RIFF_TAG = 0x52494646; // makeIntTag ("RIFF");



}



