///////////////////////////////////////////////////////////////////////////////
//                                                                           //
//  Notice to licensees:                                                     //
//                                                                           //
//  This source code is the exclusive, proprietary intellectual property of  //
//  Sharkysoft (sharkysoft.com).  You may view this source code as a         //
//  supplement to other product documentation, but you may not distribute    //
//  it or use it for any other purpose without written consent from          //
//  Sharkysoft.                                                              //
//                                                                           //
//  You are permitted to modify and recompile this source code, but you may  //
//  not remove this notice.  If you add features to or fix errors in this    //
//  code, please consider sharing your changes with Sharkysoft for possible  //
//  incorporation into future releases of the product.  Thanks!              //
//                                                                           //
//  For more information about Sharkysoft products and services, please      //
//  visit Sharkysoft on the web at                                           //
//                                                                           //
//       http://sharkysoft.com/                                              //
//                                                                           //
//  Thank you for using Lava!                                                //
//                                                                           //
///////////////////////////////////////////////////////////////////////////////



package lava.riff;



import lava.array.LittleEndianArray;
import java.io.IOException;
import java.io.File;
import java.io.RandomAccessFile;



/******************************************************************************
File-based RIFF data source.

<p><b>Details:</b>  This class is a file-<wbr>based implementation of <code>IRiffInput</code>.</p>

@author Sharky
@version 1999.09.24
@since 1999.09.24
******************************************************************************/

public class RiffInputFile
	implements IRiffInput
{



	private RandomAccessFile raf;



	/**********************************************************************
	Binds to file.

	<p><b>Details:</b>  This constructor initializes a new instance to read from the given file (<var>file</var>).</p>

	@param file the input file
	**********************************************************************/

	public RiffInputFile (File file) throws IOException
	{
		raf = new RandomAccessFile (file, "r");
	}



	public long getLength () throws IOException
	{
		return raf . length ();
	}



	public long getPosition () throws IOException
	{
		return raf . getFilePointer ();
	}



	public void setPosition (long newpos) throws IOException
	{
		raf . seek (newpos);
	}



	public int read () throws IOException
	{
		return raf . read ();
	}



	public int read (byte[] dest, int offset, int amount) throws IOException
	{
		return raf . read (dest, offset, amount);
	}



	public int read (short[] dest, int offset, int amount) throws IOException
	{
		amount *= 2;
		byte[] bytes = new byte [amount];
		int br = raf . read (bytes);
		if (br < 0)
			return -1;
		LittleEndianArray.concat (bytes, 0, dest, offset, amount);
		return br / 2;
	}



	public int read (int[] dest, int offset, int amount) throws IOException
	{
		amount *= 4;
		byte[] bytes = new byte [amount];
		int br = raf . read (bytes);
		if (br < 0)
			return -1;
		LittleEndianArray.concat (bytes, 0, dest, offset, amount);
		return br / 4;
	}



	public void free (long offset, long amount)
	{
	}



	public void close () throws IOException
	{
		raf . close ();
	}



}



