///////////////////////////////////////////////////////////////////////////////
//                                                                           //
//  Notice to licensees:                                                     //
//                                                                           //
//  This source code is the exclusive, proprietary intellectual property of  //
//  Sharkysoft (sharkysoft.com).  You may view this source code as a         //
//  supplement to other product documentation, but you may not distribute    //
//  it or use it for any other purpose without written consent from          //
//  Sharkysoft.                                                              //
//                                                                           //
//  You are permitted to modify and recompile this source code, but you may  //
//  not remove this notice.  If you add features to or fix errors in this    //
//  code, please consider sharing your changes with Sharkysoft for possible  //
//  incorporation into future releases of the product.  Thanks!              //
//                                                                           //
//  For more information about Sharkysoft products and services, please      //
//  visit Sharkysoft on the web at                                           //
//                                                                           //
//       http://sharkysoft.com/                                              //
//                                                                           //
//  Thank you for using Lava!                                                //
//                                                                           //
///////////////////////////////////////////////////////////////////////////////



package lava.riff;



import java.io.File;
import java.io.IOException;
import java.io.RandomAccessFile;



/******************************************************************************
File-based RIFF data sink.

<p><b>Details:</b>  This class is a file-<wbr>based implementation of <code>IRiffOutput</code>.</p>

@author Sharky
@version 1999.09.24
@since 1999.09.24
******************************************************************************/

public class RiffOutputFile
	implements IRiffOutput
{



	private RandomAccessFile raf;



	/**********************************************************************
	Binds to file.

	<p><b>Details:</b>  This constructor initializes a new instance to write data to the given file (<var>file</var>).  If the destination file exists, it will be deleted.</p>

	@param file the input file
	@expection IOException if an I/O error occurs.
	**********************************************************************/

	public RiffOutputFile (File dest) throws IOException
	{
		if (dest . isFile ())
			dest . delete ();
		raf = new RandomAccessFile (dest, "rw");

	}



	public void setLength (long newlen) throws IOException
	{
		raf . setLength (newlen);
	}



	public long getLength () throws IOException
	{
		return raf . length ();
	}



	public void setPosition (long pos) throws IOException
	{
//System.out.println("setPosition("+pos+")");
		raf . seek (pos);
	}



	public long getPosition () throws IOException
	{
//System.out.println("getPosition");
		return raf . getFilePointer ();
	}



	public void write (int c) throws IOException
	{
//System.out.println("write("+(byte)c+")");
		raf . write (c);
	}



	public void write (byte[] src, int offset, int amount) throws IOException
	{
//System.out.println("write(src,"+offset+","+amount+")");
		raf . write (src, offset, amount);
	}



	public void commit (long pos) throws IOException
	{
	}



	public void close () throws IOException
	{
//System.out.println("close()");
		raf . close ();
	}



}



