///////////////////////////////////////////////////////////////////////////////
//                                                                           //
//  Notice to licensees:                                                     //
//                                                                           //
//  This source code is the exclusive, proprietary intellectual property of  //
//  Sharkysoft (sharkysoft.com).  You may view this source code as a         //
//  supplement to other product documentation, but you may not distribute    //
//  it or use it for any other purpose without written consent from          //
//  Sharkysoft.                                                              //
//                                                                           //
//  You are permitted to modify and recompile this source code, but you may  //
//  not remove this notice.  If you add features to or fix errors in this    //
//  code, please consider sharing your changes with Sharkysoft for possible  //
//  incorporation into future releases of the product.  Thanks!              //
//                                                                           //
//  For more information about Sharkysoft products and services, please      //
//  visit Sharkysoft on the web at                                           //
//                                                                           //
//       http://sharkysoft.com/                                              //
//                                                                           //
//  Thank you for using Lava!                                                //
//                                                                           //
///////////////////////////////////////////////////////////////////////////////



package lava.riff;



import java.io.IOException;



/******************************************************************************
Parses RIFF data source.

<p><b>Details:</b>  A <code>RiffStreamReader</code> is a {@link RiffChunkReader <code>RiffChunkReader</code>} that provides access to the outermost chunk of a RIFF file.  This the main interface through which a client begins processing a RIFF file.</p>
******************************************************************************/

public class RiffStreamReader
	extends RiffChunkReader
{



	/**********************************************************************
	Processes RIFF header.

	<p><b>Details:</b>  This constructor initializes a new <code>RiffStreamReader</code> to consume data from the given source.  Before returning, this constructor performs an initial check to confirm that the input source appears to be a valid RIFF stream and throws an exception if the check fails.  The check is performed as follows:</p>

	<ol>
		<li>The first four bytes of the file must be the ASCII characters 'R', 'I', 'F', 'F'.
		<li>The next four bytes, taken as a little-endian, unsigned 32-bit integer (DWORD), should describe the length of the RIFF files outer data segment.  If the DWORD is even, add 8 to it; if it is odd, add 9 to it.  The resulting number should be equal to the length of the entire file.
	</ol>

	<p>If either of these two tests fail, a <code>FileFormatException</code> is thrown.  If the input source is unable to report the length of the data source, the second test will not be performed.</p>

	@param file the RIFF file to process
	@exception FileFormatException if the file's header does not conform with the RIFF standard
	**********************************************************************/

	public RiffStreamReader (IRiffInput rais) throws IOException
	{
		super (rais);
	}



	/**********************************************************************
	Closes RIFF data source.

	<p><b>Details:</b>  This method closes the RIFF data source.  All chunk readers created by this instance, including inner chunk readers created by those chunk readers, and so on, become unusable.</p>

	@exception IOException if an I/O error occurs
	**********************************************************************/

	public void close () throws IOException
	{
		rais . close ();
	}



}



