///////////////////////////////////////////////////////////////////////////////
//                                                                           //
//  Notice to licensees:                                                     //
//                                                                           //
//  This source code is the exclusive, proprietary intellectual property of  //
//  Sharkysoft (sharkysoft.com).  You may view this source code as a         //
//  supplement to other product documentation, but you may not distribute    //
//  it or use it for any other purpose without written consent from          //
//  Sharkysoft.                                                              //
//                                                                           //
//  You are permitted to modify and recompile this source code, but you may  //
//  not remove this notice.  If you add features to or fix errors in this    //
//  code, please consider sharing your changes with Sharkysoft for possible  //
//  incorporation into future releases of the product.  Thanks!              //
//                                                                           //
//  For more information about Sharkysoft products and services, please      //
//  visit Sharkysoft on the web at                                           //
//                                                                           //
//       http://sharkysoft.com/                                              //
//                                                                           //
//  Thank you for using Lava!                                                //
//                                                                           //
///////////////////////////////////////////////////////////////////////////////



package lava.riff.wave;



/******************************************************************************
RIFF-wave file constants.

<p><b>Details:</b>  <code>RIFF_WAVE</code> contains constants frequently used in WAVE files.</p>
******************************************************************************/

public class RIFF_WAVE
{



	private RIFF_WAVE () {throw new lava.UnreachableCodeException ();}



	/**********************************************************************
	The 'WAVE' type identifier.  This tag does not identify a chunk, but precedes the set of inner chunks of the main RIFF chunk.
	**********************************************************************/

	public static final int WAVE_TAG = 0x57415645; // Riff.makeIntTag ("WAVE");



	/**********************************************************************
	The 'fmt&nbsp;' chunk tag.  The fmt chunk is a mandatory inner chunk of the 'WAVE' chunk.
	**********************************************************************/

	public static final int FMT_TAG = 0x666d7420; // Riff.makeIntTag ("fmt ");



	/**********************************************************************
	The 'data' chunk tag.  The data chunk is a mandatory inner chunk of the 'WAVE' chunk.
	**********************************************************************/

	public static final int DATA_TAG = 0x64617461; // Riff.makeIntTag ("data");



	/**********************************************************************
	The 'cue&nbsp;' chunk tag.  The cue chunk contains a list of cue points.
	**********************************************************************/

	public static final int CUE_TAG = 0x63756520; // Riff.makeIntTag ("cue ");



	/**********************************************************************
	The 'fact' chunk tag.
	**********************************************************************/

	public static final int FACT_TAG = 0x66616374; // Riff.makeIntTag ("fact");



	/**********************************************************************
	The 'LIST' chunk tag.  The LIST chunk contains either wave list (identified by the 'wavl' tag) or an associated data list (identified by the 'adtl' tag).
	**********************************************************************/

	public static final int LIST_TAG = 0x4c495354; // Riff.makeIntTag ("LIST");



	/**********************************************************************
	The 'adtl' chunk tag.  An 'adtl' chunk contains miscellaneous data to associate with cue points.
	**********************************************************************/

	public static final int ADTL_TAG = 0x6164746c; // Riff.makeIntTag ("adtl");



	/**********************************************************************
	The 'labl' chunk tag.  A 'labl' chunk contains the name of a cue point.
	**********************************************************************/

	public static final int LABL_TAG = 0x6c61626c; // Riff.makeIntTag ("labl");



	/**********************************************************************
	The 'note' chunk tag.  A 'note' chunk contains comment text associated with a cue point.
	**********************************************************************/

	public static final int NOTE_TAG = 0x6e6f7465; // Riff.makeIntTag ("note");



	/**********************************************************************
	The 'plst' chunk tag.
	**********************************************************************/

	public static final int PLST_TAG = 0x706c7374; // Riff.makeIntTag ("plst");



	/**********************************************************************
	The 'file' chunk tag.  A 'file' chunk contains information described in other file formats.
	**********************************************************************/

	public static final int FILE_TAG = 0x66696c65; // Riff.makeIntTag ("file");



	/**********************************************************************
	The 'wavl' chunk tag.  A 'wavl' chunk contains either a data chunk or a 'slnt' chunk.
	**********************************************************************/

	public static final int WAVL_TAG = 0x7761766c; // Riff.makeIntTag ("wavl");



	/**********************************************************************
	The 'slnt' chunk tag.  A 'slnt' chunk describes a period of sample silence.
	**********************************************************************/

	public static final int SLNT_TAG = 0x736c6e74; // Riff.makeIntTag ("slnt");



	static final short WAVE_FORMAT_PCM = (short) 0x0001;



}



