///////////////////////////////////////////////////////////////////////////////
//                                                                           //
//  Notice to licensees:                                                     //
//                                                                           //
//  This source code is the exclusive, proprietary intellectual property of  //
//  Sharkysoft (sharkysoft.com).  You may view this source code as a         //
//  supplement to other product documentation, but you may not distribute    //
//  it or use it for any other purpose without written consent from          //
//  Sharkysoft.                                                              //
//                                                                           //
//  You are permitted to modify and recompile this source code, but you may  //
//  not remove this notice.  If you add features to or fix errors in this    //
//  code, please consider sharing your changes with Sharkysoft for possible  //
//  incorporation into future releases of the product.  Thanks!              //
//                                                                           //
//  For more information about Sharkysoft products and services, please      //
//  visit Sharkysoft on the web at                                           //
//                                                                           //
//       http://sharkysoft.com/                                              //
//                                                                           //
//  Thank you for using Lava!                                                //
//                                                                           //
///////////////////////////////////////////////////////////////////////////////



package lava.riff.wave;



import java.io.IOException;
import lava.riff.RiffChunkReader;



/******************************************************************************
Single cue point from cue points chunk.

<p><b>Details:</b>  A <code>WaveCuePoint</code> represents a single cue point entry in a .wav file's "cue" chunk.  See <a href="doc-files/riffwave-content.htm#Cue-Points Chunk">"Cue Points Chunk"</a> in <a href="doc-files/riffwave-frameset.htm"><cite>RIFF WAVE (.WAV) file format</cite></a> for a description of this class' members.</p>

@author Sharky
******************************************************************************/

public class WaveCuePoint
{



	/**********************************************************************
	dwName field.

	<p><b>Details:</b>  This is the four character name of the cue point, which is used as the key into the ADTL chunk to retrieve additional information about the cue point, such as the cue point's label.</p>

	@see WaveStreamReader#getAdtlChunkReader()
	@see WaveAdtlChunkReader
	**********************************************************************/

	public int dwName;



	/**********************************************************************
	dwPosition field.
	**********************************************************************/

	public int dwPosition;



	/**********************************************************************
	fccChunk field.
	**********************************************************************/

	public int fccChunk;



	/**********************************************************************
	dwChunkStart field.
	**********************************************************************/

	public int dwChunkStart;



	/**********************************************************************
	dwBlockStart field.
	**********************************************************************/

	public int dwBlockStart;



	/**********************************************************************
	dwSampleOffset field.
	**********************************************************************/

	public int dwSampleOffset;



	public WaveCuePoint ()
	{
	}



	WaveCuePoint (RiffChunkReader chunk, int index) throws IOException
	{
		chunk . seek (4 + (6 * 4) * index);
		dwName         = chunk . readDword ();
		dwPosition     = chunk . readDword ();
		fccChunk       = chunk . readTag   ();
		dwChunkStart   = chunk . readDword ();
		dwBlockStart   = chunk . readDword ();
		dwSampleOffset = chunk . readDword ();
	}



}



