///////////////////////////////////////////////////////////////////////////////
//                                                                           //
//  Notice to licensees:                                                     //
//                                                                           //
//  This source code is the exclusive, proprietary intellectual property of  //
//  Sharkysoft (sharkysoft.com).  You may view this source code as a         //
//  supplement to other product documentation, but you may not distribute    //
//  it or use it for any other purpose without written consent from          //
//  Sharkysoft.                                                              //
//                                                                           //
//  You are permitted to modify and recompile this source code, but you may  //
//  not remove this notice.  If you add features to or fix errors in this    //
//  code, please consider sharing your changes with Sharkysoft for possible  //
//  incorporation into future releases of the product.  Thanks!              //
//                                                                           //
//  For more information about Sharkysoft products and services, please      //
//  visit Sharkysoft on the web at                                           //
//                                                                           //
//       http://sharkysoft.com/                                              //
//                                                                           //
//  Thank you for using Lava!                                                //
//                                                                           //
///////////////////////////////////////////////////////////////////////////////



package lava.riff.wave;



import lava.konst.LONG;
import lava.konst.INT;



/******************************************************************************
Clips wave sample data.

<p><b>Details:</b> <code>WaveSampleClipper</code> is a collection of functions that clip samples to a particular range.</p>

<p>The parameters for each of these methods follow the same pattern as described in the header for class {@link WaveSampleConverter <code>WaveSampleConverter</code>}.</p>

@author Sharky
******************************************************************************/

public class WaveSampleClipper
{



	/**********************************************************************
	Clip values to legal range.

	<p><b>Details:</b>  <code>clip</code> modifies the sample data so that no value is greater than +1.0 or smaller than -1.0.  Values greater than +1.0 are set to exactly +1.0, and value smaller than -1.0 are set to exactly -1.0.</p>

	@param src source array
	@param from starting index in src
	@param dest destination array
	@param to starting index in dest
	@param amt number of values to clip
	@return destination array
	**********************************************************************/

	public static double[] clip
	(
		double[] src,
		int from,
		double[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new double [to + amt];
		for (int i = 0; i < amt; ++ i)
		{
			double d = src [from + i];
			if (d > 1)
				d = 1;
			else if (d < -1)
				d = -1;
			dest [to + i] = d;
		}
		return dest;
	}



	/**********************************************************************
	Clip values to legal range.

	<p><b>Details:</b>  <code>clip</code> modifies the sample data so that no value is greater than +1.0 or smaller than -1.0.  Values greater than +1.0 are set to exactly +1.0, and value smaller than -1.0 are set to exactly -1.0.</p>

	@param src source array
	@param from starting index in src
	@param dest destination array
	@param to starting index in dest
	@param amt number of values to clip
	@return destination array
	**********************************************************************/

	public static float[] clip
	(
		float[] src,
		int from,
		float[] dest,
		int to,
		int amt
	)
	{
		if (amt < 0)
			throw new IllegalArgumentException ("amt==" + amt);
		if (src == null)
			return null;
		if (dest == null)
			dest = new float [to + amt];
		for (int i = 0; i < amt; ++ i)
		{
			float d = src [from + i];
			if (d > 1)
				d = 1;
			else if (d < -1)
				d = -1;
			dest [to + i] = d;
		}
		return dest;
	}



}



